@@ -2,6 +2,7 @@ from sqlite3 import DataError
 import traceback
 import httpx
 from aiohttp_retry import ExponentialRetry, RetryClient
+from aiofile import async_open
 
 from qiniu import put_file, put_data, Auth, etag
 from qiniu import BucketManager, build_batch_delete
@@ -91,12 +92,12 @@ class Qiniu(BackendBase):
             async with RetryClient(retry_options=retry_opts) as session:
                 async with session.get(url) as response:
                     if response.status == 200:
-                        with open(download_path, mode='wb') as f:
+                        async with async_open(download_path, mode='wb') as f:
                             while True:
                                 chunk = await response.content.read(4096)
                                 if not chunk:
                                     break
-                                f.write(chunk)
+                                await f.write(chunk)
                     else:
                         raise DataError()
             return True, download_path
