@@ -70,7 +70,7 @@ patch_frame_config(
 
 hmfs_client = Client.get_client(opt.api_host, cache_engine.client, None)
 
-@task_deco('fs_put', function_timeout=20, concurrent_mode=4, concurrent_num=4, broker_kind=BrokerEnum.NSQ, specify_async_loop=asyncio.get_event_loop())
+@task_deco('fs_put', function_timeout=20, concurrent_mode=4, broker_kind=BrokerEnum.NSQ, specify_async_loop=asyncio.get_event_loop())
 async def file_transfer_put(url, bucket, bucket_name, ttl):
     key = 'file_transfer_put_{}_{}'.format(bucket, bucket_name)
     if await cache_engine.get_cache_async(key, return_obj=False) is not None:
@@ -83,18 +83,18 @@ async def file_transfer_put(url, bucket, bucket_name, ttl):
                     return
                 
                 file_path = os.path.join(cache_path, '{}_{}'.format(bucket, bucket_name))
-                print('downloading file from cloud....')
+                # print('downloading file from cloud....')
                 ret, e = await hmfs_client.get_from_cloud_async(file_path, url)
 
                 if ret:
-                    print('cloud downloaded. start uploading...')
+                    # print('cloud downloaded. start uploading...')
                     ret, e = minio.upload_file(e, bucket, bucket_name)
                     if ret:
                         cache_engine.cache('tmp_file_{}_{}'.format(bucket, bucket_name), {
                             'ret': True, 
                             'url': url
                         }, expired=60)
-                        print('upload success!!')
+                        # print('upload success!!')
                         
                         if ttl != -1:
                             expired_time = time.time() + ttl * 24 * 60 * 60
@@ -106,13 +106,12 @@ async def file_transfer_put(url, bucket, bucket_name, ttl):
                             'err': e
                         }, expired=60)
                 else:
-                    print('cloud download failed -> ' + e)
+                    print('fput -> cloud download failed -> ' + e)
                     cache_engine.cache('tmp_file_{}_{}'.format(bucket, bucket_name), {
                         'ret': False,
                         'err': '文件中转错误'
                     }, expired=60)
                 cache_engine.cache(key, 1, expired=60)
-                print('ok')
             except Exception as e:
                 cache_engine.cache('tmp_file_{}_{}'.format(bucket, bucket_name), {
                         'ret': False,
@@ -125,7 +124,26 @@ async def file_transfer_put(url, bucket, bucket_name, ttl):
                     }, expired=60)
 
 
-@task_deco('fs_get', function_timeout=60, concurrent_mode=4, concurrent_num=4, broker_kind=BrokerEnum.NSQ)
+def put_to_cloud(task_id, file_path, bucket, bucket_name, tries=0):
+    ret, e = hmfs_client.put_to_cloud(file_path, bucket, bucket_name)
+    if ret:
+        print('fget -> uploaded to cloud')
+        cache_engine.cache(task_id, {
+            'ret': True,
+            'url': e
+        }, expired=60 * 60 * 24 * 1)
+    else:
+        if tries > 3:
+            print('fget -> failed uploading to cloud')
+            cache_engine.cache(task_id, {
+                'ret': False, 
+                'err': e
+            }, expired=60)
+        else:
+            print('fget -> retry put to cloud') 
+            put_to_cloud(task_id, file_path, bucket, bucket_name, tries+1)
+
+@task_deco('fs_get', function_timeout=60, concurrent_mode=4, broker_kind=BrokerEnum.NSQ)
 async def file_transfer_get(bucket, bucket_name, refresh='no'):
     try:
         task_id = 'tmp_file_{}_{}'.format(bucket, bucket_name)
@@ -133,26 +151,19 @@ async def file_transfer_get(bucket, bucket_name, refresh='no'):
         if not os.path.isfile(file_path):
             ret, e = minio.download_file(file_path, bucket, bucket_name)
             if ret:
+                print('fget -> downloaded from minio')
                 file_path = e
             else:
+
+                print('fget -> failed from minio')
                 cache_engine.cache(task_id, {
                     'ret': False, 
                     'err': e.message
                 }, expired=60)
                 return
+        
 
-        ret, e = hmfs_client.put_to_cloud(file_path, bucket, bucket_name)
-        if ret:
-            cache_engine.cache(task_id, {
-                'ret': True,
-                'url': e
-            }, expired=60 * 60 * 24 * 1)
-            print('upload success!!')
-        else:
-            cache_engine.cache(task_id, {
-                'ret': False, 
-                'err': e
-            }, expired=60)
+        put_to_cloud(task_id, file_path, bucket, bucket_name)
     except Exception as e:
         traceback.print_exc()
     
